@@ -3,7 +3,7 @@ import json
 import logging
 import base64
 import os
-from kafka import KafkaConsumer
+from kafka import KafkaConsumer,TopicPartition,KafkaAdminClient
 from kafka.errors import KafkaError
 import threading
 import time
@@ -11,7 +11,7 @@ import time
 class KNativeKafkaConsumer(threading.Thread):
     daemon = True    
 
-    def __init__(self,topics:str):
+    def __init__(self,topics:str,groupid,enable_auto_commit=False):
 
         """
         Initialize a KNativeKafkaConsumer class based on the input params and the environment variables.
@@ -24,6 +24,9 @@ class KNativeKafkaConsumer(threading.Thread):
         """
         self.logger = logging.getLogger()
         self.logger.info("Initializing Kafka Consumer")
+        self.group_id = groupid
+  
+        
         if topics:
             self.topics=topics
         elif 'KAFKA_TOPIC' in os.environ:
@@ -50,14 +53,19 @@ class KNativeKafkaConsumer(threading.Thread):
             self.ssl_cafile=None
             self.ssl_certfile=None
             self.ssl_keyfile=None
+        self.logger.info("KafkaConsumer")
         self.consumer=KafkaConsumer(
-                      bootstrap_servers=bootstrap_server,                                                                                                                                                                                                                                                                                                                            
+                      bootstrap_servers=bootstrap_server,   
+                      group_id=groupid,                                                                                                                                                                                                                                                                                                                          
                       auto_offset_reset='earliest',
                       value_deserializer=bytes.decode,
                       security_protocol=self.security_protocol,
                       ssl_cafile=self.ssl_cafile,
                       ssl_certfile=self.ssl_certfile,
-                      ssl_keyfile=self.ssl_keyfile)
+                      ssl_keyfile=self.ssl_keyfile,
+                      enable_auto_commit=True,
+                      auto_commit_interval_ms=1000)
+                          
         
     def getMessage(self) -> str:
         """
@@ -77,4 +85,22 @@ class KNativeKafkaConsumer(threading.Thread):
                                                                         message.offset,
                                                                         message.key,
                                                                         message.value))
-        return message.value
\ No newline at end of file
+        return message.value
+
+    def getMetric(self):
+        for p in self.consumer.partitions_for_topic(self.topics):
+            tp = TopicPartition(self.topics, p)
+            self.consumer.assign([tp])
+            committed_offset = self.consumer.committed(tp)
+            if committed_offset is None:
+                committed_offset = 0
+            for _, v in self.consumer.end_offsets([tp]).items():
+                latest_offset = v
+            print("committed_offset")
+            print(committed_offset)
+            print("latest offset")
+            print(latest_offset)
+            print("lag")
+            print(latest_offset - committed_offset)
+
+        self.consumer.close(autocommit=False)
